get_blocks: transforms a stan file into list with named elements...

Description Usage Arguments

View source: R/stan_file_util.r

Description

transforms a stan file into list with named elements corresponding to the program block

Usage

1

Arguments

x

stan code


Christopher-Peterson/macroStan documentation built on Oct. 30, 2019, 5:42 a.m.