get_macro_calls: extracts the macro calls from the use macros block

Description Usage Arguments Value

View source: R/parse_macro.r

Description

extracts the macro calls from the use macros block

Usage

1

Arguments

blocks

a macro file parsed with 'get_blocks'

Value

a list of language objects, one per argument


Christopher-Peterson/macroStan documentation built on Oct. 30, 2019, 5:42 a.m.