parse_macro_calls: identify which macros are being used and parse them into text

Description Usage Arguments

View source: R/parse_macro.r

Description

identify which macros are being used and parse them into text

Usage

1
parse_macro_calls(scaffold_blocks, macro_list)

Arguments

scaffold_blocks

'get_blocks()' of the scaffold

macro_list

list of available macros


Christopher-Peterson/macroStan documentation built on Oct. 30, 2019, 5:42 a.m.