parse_macro_formals: parse the arguments for the R representation of a macro

Description Usage Arguments Value

View source: R/read_macro.r

Description

parse the arguments for the R representation of a macro

Usage

1

Arguments

.args

list of language objects returned by 'get_macro_args'

Value

formals for a new function


Christopher-Peterson/macroStan documentation built on Oct. 30, 2019, 5:42 a.m.